# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`azurelaagent`](#azurelaagent): Install and configure Azure Log Analytics on Windows and Linux
* [`azurelaagent::config`](#azurelaagentconfig): Change Azure Log Analytics configuration on Windows and Linux
* [`azurelaagent::config_linux`](#azurelaagentconfig_linux): Permit to set new workspace Id and Key. Remove all present workspace Ids.
* [`azurelaagent::config_proxy`](#azurelaagentconfig_proxy): Configure proxy settings after installation
* [`azurelaagent::config_proxy_linux`](#azurelaagentconfig_proxy_linux): Configure proxy settings after installation
* [`azurelaagent::config_proxy_windows`](#azurelaagentconfig_proxy_windows): Configure proxy settings after installation
* [`azurelaagent::config_windows`](#azurelaagentconfig_windows): Permit to set new workspace Id and Key. Remove all present workspace Ids.
* [`azurelaagent::install_linux`](#azurelaagentinstall_linux): Install agent on linux.
* [`azurelaagent::install_windows`](#azurelaagentinstall_windows): Install agent on windows.

## Classes

### azurelaagent

Install and configure Azure Log Analytics on Windows and Linux

#### Examples

##### Explicit data

```puppet
class { 'azurelaagent':
  azure_id     => 'your_workspace_id',
  azure_shared => 'your_shared_key',
}
```

##### Data on yaml file

```puppet
include azurelaagent
```

#### Parameters

The following parameters are available in the `azurelaagent` class.

##### `ensure`

Data type: `String`

'present' to install the agent, 'absent' to uninstall the agent

##### `azure_id`

Data type: `Optional[String]`

Azure workspace ID

Default value: `undef`

##### `azure_shared`

Data type: `Optional[String]`

Azure shared key

Default value: `undef`

##### `use_proxy`

Data type: `Optional[Boolean]`

True to use a proxy

Default value: `false`

##### `proxy`

Data type: `Optional[String]`

Proxy URL like [protocol://][user:password@]proxyhost[:port]

Default value: `undef`

### azurelaagent::config

Change Azure Log Analytics configuration on Windows and Linux

#### Examples

##### Explicit data

```puppet
class { 'azurelaagent::config':
  azure_id     => 'your_workspace_id',
  azure_shared => 'your_shared_key',
}
```

##### Data on yaml file

```puppet
include azurelaagent::config
```

#### Parameters

The following parameters are available in the `azurelaagent::config` class.

##### `azure_id`

Data type: `String`

Azure workspace ID

##### `azure_shared`

Data type: `String`

Azure shared key

### azurelaagent::config_linux

Permit to set new workspace Id and Key. Remove all present workspace Ids.

#### Examples

##### 

```puppet
class {'azurelaagent::config_linux':
  azure_id     => 'new_workspace_id',
  azure_shared => 'new_shared_key',
}
```

#### Parameters

The following parameters are available in the `azurelaagent::config_linux` class.

##### `azure_id`

Data type: `String`

The new workspace id

##### `azure_shared`

Data type: `String`

The new workspace key

##### `omsadmin_command`

Data type: `Optional[String]`



### azurelaagent::config_proxy

Configure proxy settings after installation

#### Examples

##### 

```puppet
class {'azurelaagent::config_proxy':
  proxy_server   => 'http://your.proxy:port',
  proxy_user     => 'username',
  proxy_password => 'password',
}
```

#### Parameters

The following parameters are available in the `azurelaagent::config_proxy` class.

##### `ensure`

Data type: `String`

'present' to set proxy, 'absent' to purge settings

##### `proxy_server`

Data type: `Optional[String]`

The proxy url like http://your.proxy:port

Default value: `undef`

##### `proxy_user`

Data type: `Optional[String]`

Username for proxy that require authentication

Default value: `undef`

##### `proxy_password`

Data type: `Optional[String]`

Password for proxy that require authentication

Default value: `undef`

### azurelaagent::config_proxy_linux

Configure proxy settings after installation

#### Examples

##### 

```puppet
class {'azurelaagent::config_proxy_linux':
  proxy_server   => 'http://your.proxy:port',
  proxy_user     => 'username',
  proxy_password => 'password',
}
```

#### Parameters

The following parameters are available in the `azurelaagent::config_proxy_linux` class.

##### `ensure`

Data type: `String`

'present' to set proxy, 'absent' to purge settings

##### `proxy_server`

Data type: `Optional[String]`

The proxy url like http://your.proxy:port

Default value: `undef`

##### `proxy_user`

Data type: `Optional[String]`

Username for proxy that require authentication

Default value: `undef`

##### `proxy_password`

Data type: `Optional[String]`

Password for proxy that require authentication

Default value: `undef`

##### `path_proxy_conf`

Data type: `Optional[String]`

Where's the proxy.conf file

##### `service_restart_command`

Data type: `Optional[String]`

Command to restart the omsagent

### azurelaagent::config_proxy_windows

Configure proxy settings after installation

#### Examples

##### 

```puppet
class {'azurelaagent::config_proxy_windows':
  proxy_server   => 'http://your.proxy:port',
  proxy_user     => 'username',
  proxy_password => 'password',
}
```

#### Parameters

The following parameters are available in the `azurelaagent::config_proxy_windows` class.

##### `ensure`

Data type: `String`

'present' to set proxy, 'absent' to purge settings

##### `proxy_server`

Data type: `Optional[String]`

The proxy url like http://your.proxy:port

Default value: `undef`

##### `proxy_user`

Data type: `Optional[String]`

Username for proxy that require authentication

Default value: `undef`

##### `proxy_password`

Data type: `Optional[String]`

Password for proxy that require authentication

Default value: `undef`

##### `path_to_download`

Data type: `Optional[String]`

Where to put the powershell script

### azurelaagent::config_windows

Permit to set new workspace Id and Key. Remove all present workspace Ids.

#### Examples

##### 

```puppet
class {'azurelaagent::config_windows':
  azure_id     => 'new_workspace_id',
  azure_shared => 'new_shared_key',
}
```

#### Parameters

The following parameters are available in the `azurelaagent::config_windows` class.

##### `azure_id`

Data type: `String`

The new workspace id

##### `azure_shared`

Data type: `String`

The new workspace key

##### `path_to_download`

Data type: `Optional[String]`



### azurelaagent::install_linux

To override default value use yaml file and define variables like
azurelaagent::install_linux::x64_download_path: 'https://github.com/Microsoft/OMS-Agent-for-Linux/releases/download/OMSAgent_v1.8.1.256/omsagent-1.8.1-256.universal.x64.sh'

* **See also**
https://github.com/Microsoft/OMS-Agent-for-Linux/blob/master/docs/OMS-Agent-for-Linux.md

#### Parameters

The following parameters are available in the `azurelaagent::install_linux` class.

##### `ensure`

Data type: `String`

'present' to install the agent, 'absent' to uninstall the agent

##### `azure_id`

Data type: `Optional[String]`

Azure workspace ID (passed from init.pp)

Default value: `undef`

##### `azure_shared`

Data type: `Optional[String]`

Azure shared key (passed from init.pp)

Default value: `undef`

##### `x64_download_path`

Data type: `String`

URL of the 64 bit agent

##### `x86_download_path`

Data type: `String`

URL of the 32 bit agent

##### `path_to_download`

Data type: `String`

Where to download the installer

##### `downloaded_script`

Data type: `String`

Name of the installer script

##### `use_proxy`

Data type: `Optional[Boolean]`

True to use a proxy (passed from init.pp)

Default value: `false`

##### `proxy`

Data type: `Optional[String]`

Proxy URL like [protocol://][user:password@]proxyhost[:port] (passed from init.pp)

Default value: `undef`

### azurelaagent::install_windows

To override default value use yaml file and define variables like
azurelaagent::install_windows::x64_download_path: 'https://go.microsoft.com/fwlink/?LinkId=828603'

* **See also**
https://docs.microsoft.com/it-it/azure/log-analytics/log-analytics-agent-windows?toc=/azure/azure-monitor/toc.json#install-the-agent-using-the-command-line

#### Parameters

The following parameters are available in the `azurelaagent::install_windows` class.

##### `ensure`

Data type: `String`

'present' to install the agent, 'absent' to uninstall the agent

##### `azure_id`

Data type: `Optional[String]`

Azure workspace ID (passed from init.pp)

Default value: `undef`

##### `azure_shared`

Data type: `Optional[String]`

Azure shared key (passed from init.pp)

Default value: `undef`

##### `x64_download_path`

Data type: `String`

URL of the 64 bit agent

##### `x86_download_path`

Data type: `String`

URL of the 32 bit agent

##### `path_to_download`

Data type: `String`

Where to download the installer

##### `downloaded_exe`

Data type: `String`

Name of the installer

##### `path_to_test_installation`

Data type: `String`

Agent binaries path, used in the exec resource

##### `package_name`

Data type: `String`

Package name as is in Control Panel, Programs and Features

##### `use_proxy`

Data type: `Optional[Boolean]`

True to use a proxy (passed from init.pp)

Default value: `false`

##### `proxy`

Data type: `Optional[String]`

Proxy URL like [protocol://][user:password@]proxyhost[:port] (passed from init.pp)

Default value: `undef`

